;;; data.scm --- 

;;;;   Copyright (C) 1997 GYVE Development Team
;;;;
;;;;   Author: Masatake YAMATO (masata-y@is.aist-nara.ac.jp)
;;;;   Created: Wed Oct 29 01:13:55 1997
;;;;   Time-stamp: <98/04/06 15:03:23 masata-y>
;;;;   
;;;;   This file is part of the GYVE vector based drawing editor. 
;;;;
;;;;   This program conforms GNU GENERAL PUBLIC LICENSE Version 2.
(define-module (gyve data)
  :use-module (gyve figs)
  :use-module (gyve simple-generator))

(define define-pattern gyve:figs:define-pattern)
(define define-gradation gyve:figs:define-gradation)

;; "niji"
(define-pattern "niji" 
  (list 0 0) (list 100 100) #f 
  (gyve:generator:NIJI #f 100 #f))

;; "introspective"
;; Inspired by the jacket of CD, INTROSPECTIVE/pet shop boys.
(let ((paths '())
      (orig (gyve:figs:create-path '((moveto 0 0)
				     (lineto 0 100)
				     (lineto 20 100)
				     (lineto 20 0)
				     (lineto 0 0))))
      (tmp #f)
      (tr  (gyve:figs:create-trans-matrix 20 0)))

  (gyve:figs:close-path orig)
  
  (set! tmp (gyve:figs:copy-path orig))
  (gyve:figs:set-color tmp "HotPink" #f)
  (set! paths (cons tmp paths))
  (set! orig (gyve:figs:apply-matrix orig tr))

  (set! tmp (gyve:figs:copy-path orig))
  (gyve:figs:set-color tmp "yellow" #f)
  (set! paths (cons tmp paths))
  (set! orig (gyve:figs:apply-matrix orig tr))

  (set! tmp (gyve:figs:copy-path orig))
  (gyve:figs:set-color tmp "red" #f)
  (set! paths (cons tmp paths))
  (set! orig (gyve:figs:apply-matrix orig tr))

  (set! tmp (gyve:figs:copy-path orig))
  (gyve:figs:set-color tmp "green" #f)
  (set! paths (cons tmp paths))
  (set! orig (gyve:figs:apply-matrix orig tr))

  (set! tmp (gyve:figs:copy-path orig))
  (gyve:figs:set-color tmp "HotPink" #f)
  (set! paths (cons tmp paths))
  (set! orig (gyve:figs:apply-matrix orig tr))

  (set! tmp (gyve:figs:copy-path orig))
  (gyve:figs:set-color tmp "DeepPink" #f)
  (set! paths (cons tmp paths))
  (set! orig (gyve:figs:apply-matrix orig tr))

  (set! tmp (gyve:figs:copy-path orig))
  (gyve:figs:set-color tmp "MediumOrchid" #f)
  (set! paths (cons tmp paths))
  (set! orig (gyve:figs:apply-matrix orig tr))
  (define-pattern "introspective" (list 0 0) (list 140 100) #f paths))

;; "star"
(define-pattern "star" (list 0 0) (list 30 30) (list 0.9 0.9 0.9)
  (list (gyve:figs:set-color  (gyve:generator:star 17 15 5 (list 10 10))
			(list 0.5 0.5 0.8)
			#f)
	(gyve:figs:set-color  (gyve:generator:star 17 15 5 (list 15 15))
			      (list 0.8 0.5 0.5)
			#f)
	))

;; "MetalBlueAmerica"
;; Inspired by the jacket of CD, metal blue america/Ken Ishii
(define-gradation "MetalBlueAmerica"
  (list 
   (list "red" 0.0 0.3 0.4 "blue")
   (list "blue" 0.4 0.5 0.7 "red")
   (list "red" 0.88 0.9 1.0 "blue")))

;; "SPECIAL BREW"
;; Inspired by the jacket of CD, "special brew".
(define-gradation "SPECIAL BREW"
  (list 
   (list "green" 0.0 0.3 0.5 "purple")
   (list "purple" 0.5 0.55 0.6 "red")
   (list "red" 0.6 0.8 1.0 "blue")))

;;  "SHERYL"
;; Inspired by the jacket of CD, SHERYL CROW/Sheryl Crow
(define-gradation "SHERYL"
  (list 
   (list "white" 0.0 0.3 0.5 "gray50")
   (list "gray50" 0.5 0.55 0.6 "gray70")
   (list "gray70" 0.6 0.8 0.9 "gray30")
   (list "gray30" 0.9 0.91 0.95 "gray70")
   (list "gray30" 0.95 0.96 1.0 "white")
   ))

;;
;; gradations generated by functions in utils.scm from data of the GIMP.
;;
(define-gradation "CD" (list (list (list 0.819999 0.82 0.82) 0.0 0.010566 0.023372 (list 0.879999 0.88 0.88)) (list (list 0.879999 0.88 0.88) 0.023372 0.045682 0.063439 (list 0.999999 1.0 1.0)) (list (list 0.999999 1.0 1.0) 0.063439 0.082638 0.176962 (list 0.909999 0.91 0.91)) (list (list 0.909999 0.91 0.91) 0.176962 0.205342 0.236227 (list 0.819999 0.82 0.82)) (list (list 0.819999 0.82 0.82) 0.236227 0.267623 0.281302 (list 0.903167 1.0 0.0)) (list (list 0.903167 1.0 0.0) 0.281302 0.296327 0.310518 (list 0.0 0.877893 1.0)) (list (list 0.0 0.877893 1.0) 0.310518 0.321369 0.340568 (list 0.38439 1.0 0.900682)) (list (list 0.38439 1.0 0.900682) 0.340568 0.357129 0.373957 (list 0.819999 0.82 0.82)) (list (list 0.819999 0.82 0.82) 0.373957 0.43419 0.5 (list 0.879999 0.88 0.88)) (list (list 0.819999 0.82 0.82) 0.5 0.510566 0.523372 (list 0.879999 0.88 0.88)) (list (list 0.879999 0.88 0.88) 0.523372 0.545682 0.563439 (list 0.999999 1.0 1.0)) (list (list 0.999999 1.0 1.0) 0.563439 0.582638 0.676962 (list 0.909999 0.91 0.91)) (list (list 0.909999 0.91 0.91) 0.676962 0.705342 0.736227 (list 0.819999 0.82 0.82)) (list (list 0.819999 0.82 0.82) 0.736227 0.767623 0.781302 (list 0.903167 1.0 0.0)) (list (list 0.903167 1.0 0.0) 0.781302 0.796327 0.810518 (list 0.0 0.877893 1.0)) (list (list 0.0 0.877893 1.0) 0.810518 0.821369 0.840568 (list 0.38439 1.0 0.900682)) (list (list 0.38439 1.0 0.900682) 0.840568 0.857129 0.873957 (list 0.819999 0.82 0.82)) (list (list 0.819999 0.82 0.82) 0.873957 0.93419 1.0 (list 0.879999 0.88 0.88))))
(define-gradation "Flare_Glow_Angular_1" (list (list (list 1.0 1.0 1.0) 0.0 0.006944 0.013889 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.013889 0.025598 0.038954 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.038954 0.045214 0.057874 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.057874 0.075748 0.087368 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.087368 0.097941 0.108514 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.108514 0.117085 0.135678 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.135678 0.150815 0.17251 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.17251 0.179517 0.1875 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.1875 0.196995 0.209446 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.209446 0.224645 0.239844 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.239844 0.244922 0.25 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.25 0.264853 0.278154 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.278154 0.299261 0.3125 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.3125 0.322917 0.333333 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.333333 0.340278 0.347222 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.347222 0.358932 0.372287 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.372287 0.380078 0.395833 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.395833 0.408459 0.416667 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.416667 0.429257 0.441848 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.441848 0.44923 0.465246 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.465246 0.470949 0.491374 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.491374 0.499722 0.511686 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.511686 0.515962 0.526459 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.526459 0.536698 0.54278 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.54278 0.547606 0.563613 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.563613 0.57709 0.590568 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.590568 0.600984 0.611401 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.611401 0.616671 0.624957 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.624957 0.635417 0.645833 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.645833 0.65625 0.661937 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.661937 0.673611 0.680556 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.680556 0.698664 0.70562 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.70562 0.709794 0.729167 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.729167 0.741792 0.75 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.75 0.76259 0.775181 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.775181 0.793795 0.806692 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.806692 0.811352 0.822204 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.822204 0.830219 0.835559 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.835559 0.843072 0.854167 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.854167 0.870031 0.876113 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.876113 0.88653 0.894164 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.894164 0.904024 0.913884 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.913884 0.927083 0.932303 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.932303 0.947917 0.959015 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.959015 0.96875 0.979167 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.979167 0.989583 1.0 (list 1.0 1.0 1.0))))
(define-gradation "Flare_Rays_Radial_1" (list (list (list 1.0 1.0 1.0) 0.0 0.514267 0.657763 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.657763 0.93823 1.0 (list 1.0 1.0 1.0))))
(define-gradation "Flare_Rays_Radial_2" (list (list (list 1.0 1.0 1.0) 0.0 0.18197 0.434057 (list 1.0 0.6 0.6)) (list (list 1.0 0.6 0.6) 0.434057 0.582638 1.0 (list 1.0 1.0 1.0))))
(define-gradation "Flare_Glow_Radial_2" (list (list (list 0.5 1.0 1.0) 0.0 0.260896 0.530885 (list 0.65368 0.728264 0.84632)) (list (list 0.65368 0.728264 0.84632) 0.530885 0.567758 0.646077 (list 0.622773 0.921464 0.578536)) (list (list 0.622773 0.921464 0.578536) 0.646077 0.72621 0.766467 (list 1.0 0.5 0.5)) (list (list 1.0 0.5 0.5) 0.766467 0.804674 0.88811 (list 0.75 0.5 1.0)) (list (list 0.75 0.5 1.0) 0.88811 0.966611 1.0 (list 0.5 1.0 1.0))))
(define-gradation "Flare_Glow_Radial_1" (list (list (list 1.0 1.0 1.0) 0.0 0.353923 0.535893 (list 0.780303 0.560606 1.0)) (list (list 0.780303 0.560606 1.0) 0.535893 0.5954 0.61655 (list 0.9 0.8 1.0)) (list (list 0.9 0.8 1.0) 0.61655 0.636956 0.717863 (list 0.780303 0.560606 1.0)) (list (list 0.780303 0.560606 1.0) 0.717863 0.854758 1.0 (list 0.9 0.8 1.0))))
(define-gradation "Deep_Sea" (list (list (list 0.0 0.00904 0.166667) 0.0 0.580968 0.764608 (list 0.179032 0.390004 0.621212)) (list (list 0.179032 0.390004 0.621212) 0.764608 0.888147 1.0 (list 0.0 0.969697 0.969697))))
(define-gradation "German_flag" (list (list (list 0.0 0.0 0.0) 0.0 0.166667 0.333333 (list 0.0 0.0 0.0)) (list (list 1.0 0.0 0.0) 0.333333 0.5 0.666667 (list 1.0 0.0 0.0)) (list (list 1.0 1.0 0.0) 0.666667 0.833333 1.0 (list 1.0 1.0 0.0))))
(define-gradation "Rounded_edge" (list (list (list 0.0 0.0 0.0) 0.0 0.220339 0.440678 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.440678 0.487288 0.533898 (list 0.833333 0.833333 0.833333)) (list (list 0.833333 0.833333 0.833333) 0.533898 0.580508 0.627119 (list 0.666667 0.666667 0.666667)) (list (list 0.666667 0.666667 0.666667) 0.627119 0.673729 0.720339 (list 0.5 0.5 0.5)) (list (list 0.5 0.5 0.5) 0.720339 0.766949 0.813559 (list 0.333333 0.333333 0.333333)) (list (list 0.333333 0.333333 0.333333) 0.813559 0.860169 0.90678 (list 0.166667 0.166667 0.166667)) (list (list 0.166667 0.166667 0.166667) 0.90678 0.95339 1.0 (list 0.0 0.0 0.0))))
(define-gradation "Blue_Green" (list (list (list 0.0 0.481711 1.0) 0.0 0.135225 0.565943 (list 0.28382 0.887055 1.0)) (list (list 0.28382 0.887055 1.0) 0.565943 0.918197 1.0 (list 0.0 1.0 0.631509))))
(define-gradation "Romanian_flag" (list (list (list 0.0 0.0 1.0) 0.0 0.166667 0.333333 (list 0.0 0.0 1.0)) (list (list 1.0 1.0 0.0) 0.333333 0.5 0.666667 (list 1.0 1.0 0.0)) (list (list 1.0 0.0 0.0) 0.666667 0.833333 1.0 (list 1.0 0.0 0.0))))
(define-gradation "Neon_Green" (list (list (list 0.0 1.0 0.0) 0.0 0.672788 0.699499 (list 0.129412 1.0 0.0)) (list (list 0.129412 1.0 0.0) 0.699499 0.737062 0.774624 (list 0.823529 1.0 0.807843)) (list (list 0.823529 1.0 0.807843) 0.774624 0.812187 0.84975 (list 0.196078 1.0 0.0)) (list (list 0.196078 1.0 0.0) 0.84975 0.874791 1.0 (list 0.031373 1.0 0.0))))
(define-gradation "Land_1" (list (list (list 0.047059 0.360784 0.572549) 0.0 0.348915 0.532554 (list 1.0 0.984314 0.984314)) (list (list 1.0 0.984314 0.984314) 0.532554 0.542571 0.555927 (list 0.258824 0.121569 0.035294)) (list (list 0.258824 0.121569 0.035294) 0.555927 0.582638 0.612688 (list 0.378491 0.689394 0.398544)) (list (list 0.378491 0.689394 0.398544) 0.612688 0.702838 0.948247 (list 0.058824 0.34902 0.114977)) (list (list 0.058824 0.34902 0.114977) 0.948247 0.974124 1.0 (list 0.111468 0.507576 0.162566))))
(define-gradation "Dark_1" (list (list (list 0.0 0.0 0.0) 0.0 0.315713 0.560935 (list 0.0 0.0 0.0)) (list (list 0.0 0.0 0.0) 0.560935 0.677796 0.774624 (list 0.636364 0.28 0.28)) (list (list 0.636364 0.28 0.28) 0.774624 0.923326 1.0 (list 1.0 0.895652 0.84))))
(define-gradation "Crown_molding" (list (list (list 0.0 0.0 0.0) 0.0 0.15512 0.238453 (list 0.84 0.84 0.84)) (list (list 0.84 0.84 0.84) 0.238453 0.287145 0.288815 (list 0.333333 0.333333 0.333333)) (list (list 0.333333 0.333333 0.333333) 0.288815 0.317195 0.388982 (list 0.9 0.9 0.9)) (list (list 0.9 0.9 0.9) 0.388982 0.583333 0.713411 (list 0.333333 0.333333 0.333333)) (list (list 0.333333 0.333333 0.333333) 0.713411 0.796745 0.878408 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.878408 0.949917 1.0 (list 0.0 0.0 0.0))))
(define-gradation "Radial_Glow_1" (list (list (list 1.0 1.0 1.0) 0.0 0.173623 0.350584 (list 1.0 0.737255 0.737255)) (list (list 1.0 0.737255 0.737255) 0.350584 0.375626 0.400668 (list 1.0 0.63606 0.63606)) (list (list 1.0 0.63606 0.63606) 0.400668 0.417919 0.421223 (list 1.0 0.517647 0.517647)) (list (list 1.0 0.517647 0.517647) 0.421223 0.425153 0.440735 (list 0.988235 0.501961 0.501961)) (list (list 0.988235 0.501961 0.501961) 0.440735 0.720367 1.0 (list 1.0 0.0 0.0))))
(define-gradation "Nauseating_Headache" (list (list (list 0.391197 0.651515 0.409796) 0.0 0.058431 0.098497 (list 0.49511 0.916667 0.865009)) (list (list 0.49511 0.916667 0.865009) 0.098497 0.100167 0.101836 (list 0.451393 0.80772 0.778663)) (list (list 0.451393 0.80772 0.778663) 0.101836 0.103506 0.105175 (list 0.407676 0.698774 0.692318)) (list (list 0.407676 0.698774 0.692318) 0.105175 0.106845 0.108514 (list 0.363958 0.589828 0.605972)) (list (list 0.363958 0.589828 0.605972) 0.108514 0.110184 0.111853 (list 0.320241 0.480881 0.519626)) (list (list 0.320241 0.480881 0.519626) 0.111853 0.122705 0.133556 (list 0.276524 0.371935 0.43328)) (list (list 0.276524 0.371935 0.43328) 0.133556 0.144407 0.157763 (list 0.232807 0.262989 0.346934)) (list (list 0.232807 0.262989 0.346934) 0.157763 0.161937 0.16611 (list 0.390299 0.317958 0.537879)) (list (list 0.390299 0.317958 0.537879) 0.16611 0.256469 0.313022 (list 0.145373 0.045096 0.174242)) (list (list 0.145373 0.045096 0.174242) 0.313022 0.33389 0.355175 (list 0.424242 0.065931 0.036105)) (list (list 0.424242 0.065931 0.036105) 0.355175 0.49447 0.626043 (list 0.145373 0.045096 0.174242)) (list (list 0.232807 0.262989 0.346934) 0.626043 0.635363 0.645614 (list 0.390299 0.317958 0.537879)) (list (list 0.390299 0.317958 0.537879) 0.645614 0.679871 0.724958 (list 0.145373 0.045096 0.174242)) (list (list 0.232807 0.262989 0.346934) 0.724958 0.729132 0.729132 (list 0.390299 0.317958 0.537879)) (list (list 0.390299 0.317958 0.537879) 0.729132 0.740427 0.751722 (list 0.359683 0.283851 0.492424)) (list (list 0.359683 0.283851 0.492424) 0.751722 0.763016 0.774311 (list 0.329067 0.249743 0.44697)) (list (list 0.329067 0.249743 0.44697) 0.774311 0.785606 0.796901 (list 0.298452 0.215635 0.401515)) (list (list 0.298452 0.215635 0.401515) 0.796901 0.808196 0.819491 (list 0.267836 0.181527 0.356061)) (list (list 0.267836 0.181527 0.356061) 0.819491 0.830786 0.842081 (list 0.23722 0.14742 0.310606)) (list (list 0.310606 0.0 0.003409) 0.842081 0.853375 0.86467 (list 0.424242 0.137255 0.137255)) (list (list 0.206604 0.113312 0.265152) 0.86467 0.867435 0.874067 (list 0.951331 1.0 0.487291)) (list (list 0.951331 1.0 0.487291) 0.874067 0.878939 0.88406 (list 0.951331 1.0 0.487291)) (list (list 0.951331 1.0 0.487291) 0.88406 0.893477 0.902894 (list 0.951331 1.0 0.487291)) (list (list 0.951331 1.0 0.487291) 0.902894 0.908389 0.910267 (list 0.145373 0.045096 0.174242)) (list (list 0.145373 0.045096 0.174242) 0.910267 1.0 1.0 (list 0.49511 0.916667 0.865009))))
(define-gradation "Greens" (list (list (list 0.146341 0.393939 0.133992) 0.0 0.0625 0.086811 (list 0.198883 0.3 0.135)) (list (list 0.198883 0.3 0.135) 0.086811 0.200334 0.25 (list 0.406805 0.613636 0.276136)) (list (list 0.406805 0.613636 0.276136) 0.25 0.3125 0.375 (list 0.324169 0.454545 0.114714)) (list (list 0.324169 0.454545 0.114714) 0.375 0.4375 0.500835 (list 0.098346 0.136364 0.085909)) (list (list 0.098346 0.136364 0.085909) 0.500835 0.535893 0.577629 (list 0.196692 0.272727 0.171818)) (list (list 0.23471 0.243859 0.187625) 0.577629 0.621035 0.657763 (list 0.272727 0.21499 0.203431)) (list (list 0.272727 0.21499 0.203431) 0.657763 0.709516 0.75793 (list 0.430776 0.666667 0.326636)) (list (list 0.430776 0.666667 0.326636) 0.75793 0.811352 0.839733 (list 0.36939 0.42 0.3444)) (list (list 0.36939 0.42 0.3444) 0.839733 0.96828 1.0 (list 0.091517 0.26 0.0))))
(define-gradation "Browns" (list (list (list 0.55 0.353971 0.1925) 0.0 0.055092 0.116861 (list 0.734848 0.461927 0.168587)) (list (list 0.734848 0.461927 0.168587) 0.116861 0.176962 0.253756 (list 0.55 0.328592 0.022)) (list (list 0.55 0.328592 0.022) 0.253756 0.347245 0.404006 (list 0.780303 0.457033 0.022095)) (list (list 0.780303 0.457033 0.022095) 0.404006 0.439065 0.507513 (list 0.69697 0.330262 0.221382)) (list (list 0.69697 0.330262 0.221382) 0.507513 0.562604 0.592654 (list 0.681667 0.487159 0.348063)) (list (list 0.681667 0.487159 0.348063) 0.592654 0.614357 0.644407 (list 0.722109 0.527005 0.406758)) (list (list 0.722109 0.527005 0.406758) 0.644407 0.676127 0.706177 (list 0.765919 0.57017 0.470341)) (list (list 0.765919 0.57017 0.470341) 0.706177 0.742905 0.782972 (list 0.590909 0.402374 0.336818)) (list (list 0.590909 0.402374 0.336818) 0.782972 0.850862 0.883695 (list 0.759037 0.555096 0.387109)) (list (list 0.759037 0.555096 0.387109) 0.883695 0.914858 0.934335 (list 0.679587 0.523656 0.364325)) (list (list 0.679587 0.523656 0.364325) 0.934335 0.967167 1.0 (list 0.55 0.353971 0.1925))))
(define-gradation "Purples" (list (list (list 0.30303 0.109635 0.273088) 0.0 0.057596 0.098497 (list 0.514411 0.279242 0.734848)) (list (list 0.514411 0.279242 0.734848) 0.098497 0.176962 0.228715 (list 0.604602 0.3315 0.65)) (list (list 0.604602 0.3315 0.65) 0.228715 0.347245 0.404006 (list 0.200503 0.169888 0.393939)) (list (list 0.200503 0.169888 0.393939) 0.404006 0.480801 0.544241 (list 0.500537 0.3233 0.53)) (list (list 0.500537 0.3233 0.53) 0.544241 0.628761 0.713283 (list 0.600648 0.445741 0.681667)) (list (list 0.600648 0.445741 0.681667) 0.713283 0.766491 0.819699 (list 0.700758 0.568182 0.833333)) (list (list 0.700758 0.568182 0.833333) 0.819699 0.928214 1.0 (list 0.184745 0.149793 0.219697))))
(define-gradation "Cold_Steel_2" (list (list (list 0.143939 0.013928 0.1) 0.0 0.068447 0.101836 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.101836 0.501669 0.901503 (list 0.088684 0.075143 0.174242)) (list (list 0.200503 0.169888 0.393939) 0.901503 0.929902 1.0 (list 0.047059 0.023529 0.137255))))
(define-gradation "Three_bars_sin" (list (list (list 0.0 0.0 0.0) 0.0 0.083333 0.166667 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.166667 0.25 0.333333 (list 0.0 0.0 0.0)) (list (list 0.0 0.0 0.0) 0.333333 0.416667 0.5 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.5 0.583333 0.666667 (list 0.0 0.0 0.0)) (list (list 0.0 0.0 0.0) 0.666667 0.75 0.833333 (list 0.833333 0.833333 0.833333)) (list (list 0.833333 0.833333 0.833333) 0.833333 0.916667 1.0 (list 0.0 0.0 0.0))))
(define-gradation "Romanian_flag_smooth" (list (list (list 0.0 0.0 1.0) 0.0 0.25 0.5 (list 1.0 1.0 0.0)) (list (list 1.0 1.0 0.0) 0.5 0.75 1.0 (list 1.0 0.0 0.0))))
(define-gradation "Yellow_Orange" (list (list (list 1.0 0.892593 0.0) 0.0 0.135225 0.565943 (list 1.0 0.534703 0.0)) (list (list 1.0 0.534703 0.0) 0.565943 0.948247 1.0 (list 0.901515 0.428701 0.114311))))
(define-gradation "Caribbean_Blues" (list (list (list 0.0 0.130219 0.583333) 0.0 0.403766 0.567613 (list 0.2 0.833333 0.726927)) (list (list 0.2 0.833333 0.726927) 0.567613 0.642738 0.681135 (list 1.0 0.988352 0.86)) (list (list 1.0 0.988352 0.86) 0.681135 0.790397 1.0 (list 0.0 0.431818 0.0))))
(define-gradation "Full_saturation_spectrum_CW" (list (list (list 1.0 0.0 0.0) 0.0 0.5 1.0 (list 1.0 0.0 0.0))))
(define-gradation "Flare_Sizefac_101" (list (list (list 0.37 0.37 0.37) 0.0 0.5 1.0 (list 1.0 1.0 1.0))))
(define-gradation "Tube_Red" (list (list (list 0.0 0.0 0.0) 0.0 0.189482 0.378965 (list 0.0 0.0 0.0)) (list (list 0.0 0.0 0.0) 0.378965 0.624374 0.721202 (list 0.0 0.0 0.0)) (list (list 0.393939 0.091171 0.035564) 0.721202 0.748748 0.776294 (list 0.204545 0.047339 0.018466)) (list (list 0.204545 0.047339 0.018466) 0.776294 0.833723 0.859766 (list 0.757576 0.175329 0.068392)) (list (list 0.757576 0.175329 0.068392) 0.859766 0.876461 0.893155 (list 1.0 0.501132 0.42)) (list (list 1.0 0.501132 0.42) 0.893155 0.911519 0.928214 (list 0.757576 0.175329 0.068392)) (list (list 0.757576 0.175329 0.068392) 0.928214 0.964107 1.0 (list 0.757576 0.175329 0.068392))))
(define-gradation "Aneurism" (list (list (list 0.0 0.0 0.0) 0.0 0.119571 0.235803 (list 0.202999 0.003788 0.265152)) (list (list 0.202999 0.003788 0.265152) 0.235803 0.306652 0.377501 (list 0.300711 0.001894 0.393939)) (list (list 0.300711 0.001894 0.393939) 0.377501 0.409118 0.437396 (list 0.388992 9.47e-4 0.206459)) (list (list 0.388992 9.47e-4 0.206459) 0.437396 0.45576 0.474124 (list 0.689394 0.0 0.027414)) (list (list 0.689394 0.0 0.027414) 0.474124 0.504174 0.534224 (list 0.388992 9.47e-4 0.206459)) (list (list 0.388992 9.47e-4 0.206459) 0.534224 0.571786 0.609349 (list 0.300711 0.001894 0.393939)) (list (list 0.300711 0.001894 0.393939) 0.609349 0.708556 0.770562 (list 0.202999 0.003788 0.265152)) (list (list 0.202999 0.003788 0.265152) 0.770562 0.885281 1.0 (list 0.0 0.0 0.0))))
(define-gradation "Burning_Paper" (list (list (list 1.0 1.0 1.0) 0.0 0.264608 0.502504 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.502504 0.601002 0.63773 (list 0.0 0.0 0.0)) (list (list 0.0 0.0 0.0) 0.63773 0.700343 0.744574 (list 0.89 0.329199 0.177758)) (list (list 0.89 0.329199 0.177758) 0.744574 0.767761 0.786311 (list 1.0 1.0 0.0)) (list (list 1.0 1.0 0.0) 0.786311 0.82992 0.891486 (list 0.91 0.574437 0.0)) (list (list 0.91 0.574437 0.0) 0.891486 0.944908 1.0 (list 0.727273 0.127938 0.14837))))
(define-gradation "Default" (list (list (list 0.0 0.0 0.0) 0.0 0.5 1.0 (list 1.0 1.0 1.0))))
(define-gradation "French_flag_smooth" (list (list (list 0.0 0.0 1.0) 0.0 0.25 0.5 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.5 0.75 1.0 (list 1.0 0.0 0.0))))
(define-gradation "Burning_Transparency" (list (list (list 0.0 0.0 0.0) 0.0 0.264608 0.502504 (list 0.0 0.0 0.0)) (list (list 0.0 0.0 0.0) 0.502504 0.601002 0.63773 (list 0.0 0.0 0.0)) (list (list 0.0 0.0 0.0) 0.63773 0.700343 0.744574 (list 0.89 0.329199 0.177758)) (list (list 0.89 0.329199 0.177758) 0.744574 0.767761 0.786311 (list 1.0 1.0 0.0)) (list (list 1.0 1.0 0.0) 0.786311 0.82992 0.891486 (list 0.91 0.574437 0.0)) (list (list 0.91 0.574437 0.0) 0.891486 0.944908 1.0 (list 0.727273 0.127938 0.14837))))
(define-gradation "Tropical_Colors" (list (list (list 0.036578 0.159091 0.015374) 0.0 0.055556 0.085142 (list 0.007899 0.310606 0.0)) (list (list 0.007899 0.310606 0.0) 0.085142 0.138564 0.193656 (list 0.195893 0.575758 0.085655)) (list (list 0.195893 0.575758 0.085655) 0.193656 0.233723 0.276572 (list 0.924242 0.750598 0.192395)) (list (list 0.924242 0.750598 0.192395) 0.276572 0.332128 0.387683 (list 0.954545 0.239854 0.132221)) (list (list 0.954545 0.239854 0.132221) 0.387683 0.510851 0.555556 (list 0.530303 0.319349 0.236012)) (list (list 0.530303 0.319349 0.236012) 0.555556 0.611111 0.666667 (list 0.472649 0.295792 1.0)) (list (list 0.472649 0.295792 1.0) 0.666667 0.772955 0.826377 (list 0.644153 1.0 0.957743)) (list (list 0.644153 1.0 0.957743) 0.826377 0.866444 0.884808 (list 0.408723 0.87 0.2784)) (list (list 0.408723 0.87 0.2784) 0.884808 0.953255 1.0 (list 0.363558 0.5 0.0))))
(define-gradation "Square_Wood_Frame" (list (list (list 0.348485 0.187023 0.02707) 0.0 0.394306 0.797162 (list 0.348485 0.187023 0.02707)) (list (list 0.348485 0.187023 0.02707) 0.797162 0.813856 0.830551 (list 0.598485 0.321191 0.04649)) (list (list 0.757576 0.430331 0.081217) 0.830551 0.880217 0.929883 (list 0.757576 0.430331 0.081217)) (list (list 0.757576 0.430331 0.081217) 0.929883 0.939294 0.949647 (list 1.0 0.681967 0.42)) (list (list 1.0 0.681967 0.42) 0.949647 0.962907 0.976169 (list 0.757576 0.424126 0.068392)) (list (list 0.757576 0.424126 0.068392) 0.976169 0.988085 1.0 (list 0.481061 0.26695 0.042141))))
(define-gradation "German_flag_smooth" (list (list (list 0.0 0.0 0.0) 0.0 0.25 0.5 (list 1.0 0.0 0.0)) (list (list 1.0 0.0 0.0) 0.5 0.75 1.0 (list 1.0 1.0 0.0))))
(define-gradation "Radial_Eyeball_Green" (list (list (list 0.0 0.0 0.0) 0.0 0.105175 0.198664 (list 0.0 0.0 0.0)) (list (list 0.0 0.709804 0.423529) 0.198664 0.352254 0.492487 (list 0.0 0.356863 0.094118)) (list (list 1.0 1.0 1.0) 0.492487 0.63606 0.78798 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.78798 0.931553 0.996661 (list 1.0 0.619608 0.619608)) (list (list 1.0 0.619608 0.619608) 0.996661 0.996661 1.0 (list 1.0 0.619608 0.619608))))
(define-gradation "Mexican_flag" (list (list (list 0.0 1.0 0.0) 0.0 0.166667 0.333333 (list 0.0 1.0 0.0)) (list (list 1.0 1.0 1.0) 0.333333 0.5 0.666667 (list 1.0 1.0 1.0)) (list (list 1.0 0.0 0.0) 0.666667 0.833333 1.0 (list 1.0 0.0 0.0))))
(define-gradation "French_flag" (list (list (list 0.0 0.0 1.0) 0.0 0.166667 0.333333 (list 0.0 0.0 1.0)) (list (list 1.0 1.0 1.0) 0.333333 0.5 0.666667 (list 1.0 1.0 1.0)) (list (list 1.0 0.0 0.0) 0.666667 0.833333 1.0 (list 1.0 0.0 0.0))))
(define-gradation "Skyline" (list (list (list 0.0 0.0 0.0) 0.0 0.051753 0.365609 (list 0.109804 0.066667 0.568627)) (list (list 0.109804 0.066667 0.568627) 0.365609 0.602671 0.749583 (list 0.917647 0.043137 0.043137)) (list (list 0.917647 0.043137 0.043137) 0.749583 0.789649 0.864775 (list 1.0 0.533333 0.0)) (list (list 1.0 0.533333 0.0) 0.864775 0.896494 0.934891 (list 0.937255 0.92549 0.215686)) (list (list 0.537255 0.396078 0.031373) 0.934891 0.958264 1.0 (list 0.0 0.0 0.0))))
(define-gradation "Flare_Radial_101" (list (list (list 1.0 0.999999 0.999999) 0.0 0.050918 0.101836 (list 1.0 0.999999 0.999999)) (list (list 1.0 0.999999 0.999999) 0.101836 0.151085 0.200334 (list 1.0 0.691315 0.691315)) (list (list 1.0 0.691315 0.691315) 0.200334 0.250417 0.300501 (list 1.0 0.590658 0.590658)) (list (list 1.0 0.590658 0.590658) 0.300501 0.350584 0.400668 (list 1.0 0.49 0.49)) (list (list 1.0 0.49 0.49) 0.400668 0.45576 0.5 (list 1.0 0.3 0.3)) (list (list 1.0 0.3 0.3) 0.5 0.511269 0.51586 (list 1.0 0.3 0.3)) (list (list 1.0 0.3 0.3) 0.51586 0.601002 1.0 (list 1.0 1.0 1.0))))
(define-gradation "Flare_Radial_102" (list (list (list 1.0 1.0 1.0) 0.0 0.024937 0.058431 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.058431 0.083751 0.105175 (list 1.0 0.49 0.49)) (list (list 1.0 0.49 0.49) 0.105175 0.157763 0.208681 (list 1.0 0.25 0.25)) (list (list 1.0 0.25 0.25) 0.208681 0.278798 0.405676 (list 1.0 0.25 0.25)) (list (list 1.0 0.25 0.25) 0.405676 0.534224 0.799666 (list 1.0 0.25 0.25)) (list (list 1.0 0.25 0.25) 0.799666 0.899833 1.0 (list 1.0 0.25 0.25))))
(define-gradation "Flare_Radial_103" (list (list (list 1.0 1.0 1.0) 0.0 0.517529 1.0 (list 1.0 0.51 0.51))))
(define-gradation "Shadows_2" (list (list (list 0.462121 0.462121 0.462121) 0.0 0.048414 0.126878 (list 0.94 0.865112 0.8178)) (list (list 0.94 0.865112 0.8178) 0.126878 0.368948 0.499165 (list 0.38 0.328734 0.231331)) (list (list 0.38 0.328734 0.231331) 0.499165 0.602671 0.739566 (list 0.55303 0.482304 0.336911)) (list (list 0.55303 0.482304 0.336911) 0.739566 0.76635 0.854758 (list 0.007576 0.007576 0.007576)) (list (list 0.007576 0.007576 0.007576) 0.854758 0.968292 1.0 (list 0.659091 0.659091 0.659091))))
(define-gradation "Shadows_1" (list (list (list 0.113636 0.113636 0.113636) 0.0 0.22158 0.346912 (list 0.643939 0.311237 0.107323)) (list (list 0.643939 0.311237 0.107323) 0.346912 0.449416 0.538564 (list 0.871212 0.82 0.82)) (list (list 0.871212 0.82 0.82) 0.538564 0.617696 0.652755 (list 0.34 0.128091 0.107291)) (list (list 0.34 0.128091 0.107291) 0.652755 0.747913 0.777963 (list 1.0 0.52199 0.22)) (list (list 1.0 0.52199 0.22) 0.777963 0.854667 1.0 (list 0.204545 0.121376 0.046011))))
(define-gradation "Neon_Yellow" (list (list (list 1.0 0.94902 0.0) 0.0 0.672788 0.699499 (list 1.0 0.933333 0.0)) (list (list 1.0 0.933333 0.0) 0.699499 0.737062 0.774624 (list 0.996078 1.0 0.819608)) (list (list 1.0 0.996078 0.819608) 0.774624 0.812187 0.84975 (list 1.0 0.94902 0.0)) (list (list 1.0 0.94902 0.0) 0.84975 0.874791 1.0 (list 1.0 0.94902 0.0))))
(define-gradation "Neon_Cyan" (list (list (list 0.0 1.0 0.94902) 0.0 0.672788 0.699499 (list 0.0 1.0 0.933333)) (list (list 0.0 1.0 0.913725) 0.699499 0.737062 0.774624 (list 0.827451 1.0 0.988235)) (list (list 0.827451 1.0 0.984314) 0.774624 0.812187 0.84975 (list 0.0 1.0 0.913725)) (list (list 0.0 1.0 0.913725) 0.84975 0.874791 1.0 (list 0.0 1.0 0.933333))))
(define-gradation "Four_bars" (list (list (list 0.0 0.0 0.0) 0.0 0.0625 0.125 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.125 0.1875 0.25 (list 0.0 0.0 0.0)) (list (list 0.0 0.0 0.0) 0.25 0.3125 0.375 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.375 0.4375 0.5 (list 0.0 0.0 0.0)) (list (list 0.0 0.0 0.0) 0.5 0.5625 0.625 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.625 0.6875 0.75 (list 0.0 0.0 0.0)) (list (list 0.0 0.0 0.0) 0.75 0.8125 0.875 (list 0.875 0.875 0.875)) (list (list 0.875 0.875 0.875) 0.875 0.9375 1.0 (list 0.0 0.0 0.0))))
(define-gradation "Mexican_flag_smooth" (list (list (list 0.0 1.0 0.0) 0.0 0.25 0.5 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.5 0.75 1.0 (list 1.0 0.0 0.0))))
(define-gradation "Radial_Eyeball_Brown" (list (list (list 0.0 0.0 0.0) 0.0 0.105175 0.198664 (list 0.0 0.0 0.0)) (list (list 0.478431 0.380392 0.0) 0.198664 0.352254 0.492487 (list 0.298039 0.227451 0.0)) (list (list 1.0 1.0 1.0) 0.492487 0.63606 0.78798 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.78798 0.931553 0.996661 (list 1.0 0.619608 0.619608)) (list (list 1.0 0.619608 0.619608) 0.996661 0.996661 1.0 (list 1.0 0.619608 0.619608))))
(define-gradation "Radial_Rainbow_Hoop" (list (list (list 0.0 1.0 0.0) 0.0 0.66611 0.699499 (list 1.0 0.113725 0.0)) (list (list 1.0 0.113725 0.0) 0.699499 0.767947 0.84975 (list 1.0 0.0 0.047059)) (list (list 1.0 0.0 0.047059) 0.84975 0.87813 1.0 (list 1.0 0.431373 0.0))))
(define-gradation "Brushed_Aluminium" (list (list (list 0.435294 0.447059 0.411765) 0.0 0.03125 0.041736 (list 0.49807 0.508364 0.477482)) (list (list 0.49807 0.508364 0.477482) 0.041736 0.066308 0.072621 (list 0.529458 0.539017 0.51034)) (list (list 0.54902 0.556863 0.529412) 0.072621 0.081803 0.125 (list 0.560845 0.569669 0.543199)) (list (list 0.560845 0.569669 0.543199) 0.125 0.130217 0.154946 (list 0.623621 0.630974 0.608916)) (list (list 0.623621 0.630974 0.608916) 0.154946 0.186196 0.203255 (list 0.686397 0.692279 0.674632)) (list (list 0.686397 0.692279 0.674632) 0.203255 0.278798 0.285476 (list 0.749173 0.753585 0.740349)) (list (list 0.749173 0.753585 0.740349) 0.285476 0.320534 0.33389 (list 0.811948 0.81489 0.806066)) (list (list 0.756863 0.756863 0.756863) 0.33389 0.33389 0.365609 (list 0.843336 0.845542 0.838925)) (list (list 0.843336 0.845542 0.838925) 0.365609 0.39399 0.399833 (list 0.8 0.796078 0.756863)) (list (list 0.8 0.796078 0.756863) 0.399833 0.485392 0.517529 (list 0.9375 0.9375 0.9375)) (list (list 0.9375 0.9375 0.9375) 0.517529 0.53125 0.552483 (list 0.772549 0.772549 0.772549)) (list (list 0.658824 0.658824 0.658824) 0.552483 0.563439 0.569282 (list 0.784314 0.784314 0.8)) (list (list 0.784314 0.784314 0.8) 0.569282 0.577629 0.586394 (list 0.823529 0.811765 0.811765)) (list (list 0.823529 0.811765 0.811765) 0.586394 0.618322 0.626043 (list 0.726583 0.728537 0.731807)) (list (list 0.726583 0.728537 0.731807) 0.626043 0.641068 0.663606 (list 0.737255 0.760784 0.721569)) (list (list 0.737255 0.760784 0.721569) 0.663606 0.675292 0.682805 (list 0.621109 0.628462 0.613266)) (list (list 0.621109 0.628462 0.613266) 0.682805 0.703673 0.722473 (list 0.529412 0.529412 0.529412)) (list (list 0.529412 0.529412 0.529412) 0.722473 0.74668 0.758765 (list 0.498039 0.492157 0.472549)) (list (list 0.447059 0.443137 0.427451) 0.758765 0.763773 0.770451 (list 0.560784 0.537255 0.54902)) (list (list 0.513725 0.517647 0.501961) 0.770451 0.799145 0.827838 (list 0.486417 0.479213 0.477687)) (list (list 0.486417 0.479213 0.477687) 0.827838 0.83389 0.851419 (list 0.477872 0.467187 0.470092)) (list (list 0.477872 0.467187 0.470092) 0.851419 0.876461 0.892321 (list 0.469328 0.455162 0.462497)) (list (list 0.469328 0.455162 0.462497) 0.892321 0.934474 0.941569 (list 0.478431 0.462745 0.470588)) (list (list 0.465056 0.44915 0.458699) 0.941569 0.965776 1.0 (list 0.556863 0.537255 0.552941))))
(define-gradation "Blinds" (list (list (list 0.0 0.0 0.0) 0.0 0.041667 0.166667 (list 0.5 0.5 0.5)) (list (list 0.5 0.5 0.5) 0.166667 0.186978 0.25 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.25 0.25 0.346689 (list 0.0 0.0 0.0)) (list (list 0.0 0.0 0.0) 0.346689 0.42571 0.42571 (list 0.5 0.5 0.5)) (list (list 0.5 0.5 0.5) 0.42571 0.541667 0.583333 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.583333 0.583333 0.671119 (list 0.0 0.0 0.0)) (list (list 0.0 0.0 0.0) 0.671119 0.761269 0.835003 (list 0.416667 0.416667 0.416667)) (list (list 0.416667 0.416667 0.416667) 0.835003 0.875 0.916667 (list 0.833333 0.833333 0.833333)) (list (list 0.833333 0.833333 0.833333) 0.916667 0.916667 1.0 (list 0.0 0.0 0.0))))
(define-gradation "Radial_Eyeball_Blue" (list (list (list 0.0 0.0 0.0) 0.0 0.105175 0.198664 (list 0.0 0.0 0.0)) (list (list 0.0 0.035294 0.729412) 0.198664 0.352254 0.492487 (list 0.0 0.015686 0.376471)) (list (list 1.0 1.0 1.0) 0.492487 0.63606 0.78798 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.78798 0.931553 0.996661 (list 1.0 0.619608 0.619608)) (list (list 1.0 0.619608 0.619608) 0.996661 0.996661 1.0 (list 1.0 0.619608 0.619608))))
(define-gradation "Cold_Steel" (list (list (list 1.0 1.0 1.0) 0.0 0.208681 0.647746 (list 0.047059 0.023529 0.137255)) (list (list 0.047059 0.023529 0.137255) 0.647746 0.669449 1.0 (list 0.364706 0.733333 0.756863))))
(define-gradation "Incandescent" (list (list (list 0.0 0.0 0.0) 0.0 0.459098 0.594324 (list 0.729412 0.0 0.0)) (list (list 0.729412 0.0 0.0) 0.594324 0.677796 0.809683 (list 1.0 0.545098 0.196078)) (list (list 1.0 0.545098 0.196078) 0.809683 0.853088 0.899833 (list 0.972549 0.937255 0.07451)) (list (list 0.972549 0.937255 0.07451) 0.899833 0.948247 1.0 (list 0.976471 0.968627 0.831373))))
(define-gradation "Skyline_polluted" (list (list (list 0.0 0.0 0.0) 0.0 0.051753 0.365609 (list 0.227451 0.207843 0.486275)) (list (list 0.227451 0.207843 0.486275) 0.365609 0.602671 0.749583 (list 0.709804 0.098039 0.098039)) (list (list 0.709804 0.098039 0.098039) 0.749583 0.789649 0.864775 (list 0.819608 0.505882 0.270588)) (list (list 0.819608 0.505882 0.270588) 0.864775 0.896494 0.934891 (list 0.8 0.784314 0.564706)) (list (list 0.537255 0.396078 0.031373) 0.934891 0.958264 1.0 (list 0.0 0.0 0.0))))
(define-gradation "Horizon_2" (list (list (list 0.047059 0.360784 0.572549) 0.0 0.290484 0.348915 (list 0.370303 0.628966 0.787879)) (list (list 0.370303 0.628966 0.787879) 0.348915 0.470785 0.532554 (list 1.0 0.984314 0.984314)) (list (list 1.0 0.984314 0.984314) 0.532554 0.542571 0.555927 (list 0.039048 0.13298 0.265152)) (list (list 0.039048 0.13298 0.265152) 0.555927 0.582638 0.612688 (list 0.5225 0.823569 0.95)) (list (list 0.5225 0.823569 0.95) 0.612688 0.754591 1.0 (list 0.0875 0.131053 0.25))))
(define-gradation "Horizon_1" (list (list (list 0.047059 0.360784 0.572549) 0.0 0.348915 0.532554 (list 1.0 0.984314 0.984314)) (list (list 1.0 0.984314 0.984314) 0.532554 0.542571 0.555927 (list 0.258824 0.121569 0.035294)) (list (list 0.258824 0.121569 0.035294) 0.555927 0.582638 0.612688 (list 1.0 0.811765 0.54902)) (list (list 1.0 0.811765 0.54902) 0.612688 0.778798 0.948247 (list 0.34902 0.160784 0.058824)) (list (list 0.34902 0.160784 0.058824) 0.948247 0.974124 1.0 (list 1.0 0.556863 0.219608))))
(define-gradation "Sunrise" (list (list (list 1.0 1.0 1.0) 0.0 0.101798 0.203595 (list 0.948165 0.969697 0.812122)) (list (list 0.948165 0.969697 0.812122) 0.203595 0.379143 0.487479 (list 1.0 0.552632 0.27)) (list (list 1.0 0.552632 0.27) 0.487479 0.503577 0.529137 (list 0.581721 0.096155 0.170043)) (list (list 0.581721 0.096155 0.170043) 0.529137 0.545165 0.562604 (list 0.287879 0.155229 0.049835)) (list (list 0.287879 0.155229 0.049835) 0.562604 0.609349 0.69783 (list 0.336 0.425966 0.8)) (list (list 0.336 0.425966 0.8) 0.69783 0.845064 1.0 (list 0.852165 0.98593 1.0))))
(define-gradation "Full_saturation_spectrum_CCW" (list (list (list 1.0 0.0 0.0) 0.0 0.5 1.0 (list 1.0 0.0 0.0))))
(define-gradation "Flare_Rays_Size_1" (list (list (list 1.0 1.0 1.0) 0.0 0.03125 0.0625 (list 0.24 0.24 0.24)) (list (list 0.24 0.24 0.24) 0.0625 0.117659 0.153589 (list 0.86 0.86 0.86)) (list (list 0.86 0.86 0.86) 0.153589 0.161496 0.1875 (list 0.73 0.73 0.73)) (list (list 0.73 0.73 0.73) 0.1875 0.225376 0.25 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.25 0.287771 0.325543 (list 0.51 0.51 0.51)) (list (list 0.51 0.51 0.51) 0.325543 0.341148 0.375 (list 0.61 0.61 0.61)) (list (list 0.61 0.61 0.61) 0.375 0.388982 0.439065 (list 0.77 0.77 0.77)) (list (list 0.77 0.77 0.77) 0.439065 0.464107 0.5 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.5 0.529215 0.5625 (list 0.28 0.28 0.28)) (list (list 0.28 0.28 0.28) 0.5625 0.610093 0.628339 (list 0.76 0.76 0.76)) (list (list 0.76 0.76 0.76) 0.628339 0.659589 0.690839 (list 0.42 0.42 0.42)) (list (list 0.42 0.42 0.42) 0.690839 0.720419 0.75 (list 1.0 1.0 1.0)) (list (list 1.0 1.0 1.0) 0.75 0.78125 0.8125 (list 0.49 0.49 0.49)) (list (list 0.49 0.49 0.49) 0.8125 0.84375 0.856427 (list 0.0 0.0 0.0)) (list (list 0.0 0.0 0.0) 0.856427 0.90625 0.9375 (list 0.76 0.76 0.76)) (list (list 0.76 0.76 0.76) 0.9375 0.96875 1.0 (list 1.0 1.0 1.0))))
(define-gradation "Pastel_Rainbow" (list (list (list 1.0 0.74902 0.74902) 0.0 0.5 1.0 (list 1.0 0.74902 0.74902))))
(define-gradation "CD_Half" (list (list (list 0.819999 0.82 0.82) 0.0 0.021131 0.046745 (list 0.879999 0.88 0.88)) (list (list 0.879999 0.88 0.88) 0.046745 0.091364 0.126878 (list 0.999999 1.0 1.0)) (list (list 0.999999 1.0 1.0) 0.126878 0.165275 0.353923 (list 0.909999 0.91 0.91)) (list (list 0.909999 0.91 0.91) 0.353923 0.410684 0.472454 (list 0.819999 0.82 0.82)) (list (list 0.819999 0.82 0.82) 0.472454 0.535246 0.562604 (list 0.903167 1.0 0.0)) (list (list 0.903167 1.0 0.0) 0.562604 0.592654 0.621035 (list 0.0 0.877893 1.0)) (list (list 0.0 0.877893 1.0) 0.621035 0.642738 0.681135 (list 0.38439 1.0 0.900682)) (list (list 0.38439 1.0 0.900682) 0.681135 0.714259 0.747913 (list 0.819999 0.82 0.82)) (list (list 0.819999 0.82 0.82) 0.747913 0.868381 1.0 (list 0.879999 0.88 0.88))))
(define-gradation "Golden" (list (list (list 0.137255 0.156863 0.01176) 0.0 0.080316 0.163606 (list 0.53333 0.4156 0.08627)) (list (list 0.53333 0.4156 0.08627) 0.163606 0.193879 0.224151 (list 0.65 0.55 0.161)) (list (list 0.65 0.55 0.161) 0.224151 0.254424 0.284697 (list 0.8 0.71 0.29)) (list (list 0.8 0.71 0.29) 0.284697 0.314969 0.345242 (list 0.92 0.859 0.4)) (list (list 0.92 0.859 0.4) 0.345242 0.382304 0.414023 (list 0.96 0.925 0.44)) (list (list 0.96 0.925 0.44) 0.414023 0.467446 0.516416 (list 0.82 0.745 0.298)) (list (list 0.82 0.745 0.298) 0.516416 0.541681 0.571953 (list 0.7333 0.612 0.2)) (list (list 0.7333 0.612 0.2) 0.571953 0.602226 0.632499 (list 0.6588 0.5569 0.165)) (list (list 0.6588 0.5569 0.165) 0.632499 0.662771 0.698052 (list 0.79216 0.6823 0.266667)) (list (list 0.79216 0.6823 0.266667) 0.698052 0.728325 0.75793 (list 0.855 0.792 0.337)) (list (list 0.855 0.792 0.337) 0.75793 0.787201 0.817474 (list 0.816 0.7333 0.2863)) (list (list 0.816 0.7333 0.2863) 0.817474 0.847746 0.878019 (list 0.7333 0.612 0.2)) (list (list 0.7333 0.612 0.2) 0.878019 0.906511 0.934891 (list 0.537 0.4235 0.101)) (list (list 0.537 0.4235 0.101) 0.934891 0.973289 1.0 (list 0.137255 0.156863 0.01176))))
(define-gradation "Wood_2" (list (list (list 1.0 0.7 0.4) 0.0 0.069491 0.138982 (list 0.944844 0.616991 0.289137)) (list (list 0.8 0.522406 0.244813) 0.138982 0.208472 0.277963 (list 0.92886 0.592934 0.257008)) (list (list 0.82 0.523444 0.226888) 0.277963 0.347454 0.416945 (list 0.92212 0.582791 0.243462)) (list (list 0.77 0.486649 0.203299) 0.416945 0.486436 0.555927 (list 0.92 0.5796 0.2392)) (list (list 0.78 0.4914 0.2028) 0.555927 0.60914 0.662354 (list 0.903086 0.568944 0.234802)) (list (list 0.81 0.5103 0.2106) 0.662354 0.715568 0.768781 (list 0.850329 0.535708 0.221086)) (list (list 0.76 0.4788 0.1976) 0.768781 0.821995 0.875209 (list 0.708598 0.446417 0.184235)) (list (list 0.62 0.3906 0.1612) 0.875209 0.928422 0.981636 (list 0.0 0.0 0.0)) (list (list 0.0 0.0 0.0) 0.981636 0.991653 1.0 (list 0.0 0.0 0.0))))
(define-gradation "Wood_1" (list (list (list 1.0 0.7 0.4) 0.0 0.252087 0.555927 (list 0.92 0.5796 0.2392)) (list (list 0.92 0.5796 0.2392) 0.555927 0.834725 0.981636 (list 0.0 0.0 0.0)) (list (list 0.0 0.0 0.0) 0.981636 0.991653 1.0 (list 0.0 0.0 0.0))))
(define-gradation "Abstract_2" (list (list (list 1.0 0.0 0.055296) 0.0 0.333532 0.570952 (list 0.922731 0.452483 0.984953)) (list (list 0.922731 0.452483 0.984953) 0.570952 0.616469 0.664441 (list 0.122236 0.31984 0.583333)) (list (list 0.122236 0.31984 0.583333) 0.664441 0.72788 0.75626 (list 0.059646 1.0 0.558369)) (list (list 0.059646 1.0 0.558369) 0.75626 0.799666 0.843072 (list 0.969697 0.948568 0.533333)) (list (list 0.969697 0.948568 0.533333) 0.843072 0.905766 0.949917 (list 1.0 0.49 1.0)) (list (list 1.0 0.49 1.0) 0.949917 0.988314 1.0 (list 0.238108 0.191841 1.0))))
(define-gradation "Abstract_3" (list (list (list 0.0 0.424242 0.070751) 0.0 0.050083 0.435726 (list 1.0 0.725647 0.428066)) (list (list 1.0 0.725647 0.428066) 0.435726 0.490818 0.590985 (list 0.115248 0.249315 0.651515)) (list (list 0.115248 0.249315 0.651515) 0.590985 0.660267 0.799666 (list 0.552948 0.624658 0.550758)) (list (list 0.552948 0.624658 0.550758) 0.799666 0.8798 0.943239 (list 0.990647 1.0 0.45)) (list (list 0.990647 1.0 0.45) 0.943239 0.961603 0.979967 (list 0.317635 0.843781 1.0)) (list (list 0.317635 0.843781 1.0) 0.979967 0.989983 1.0 (list 0.0 1.0 0.0))))
(define-gradation "Abstract_1" (list (list (list 0.269543 0.259267 1.0) 0.0 0.286311 0.572621 (list 0.215635 0.407414 0.984953)) (list (list 0.215635 0.407414 0.984953) 0.572621 0.657763 0.716194 (list 0.040368 0.833333 0.619375)) (list (list 0.040368 0.833333 0.619375) 0.716194 0.734558 0.749583 (list 0.68049 0.355264 0.97743)) (list (list 0.68049 0.355264 0.97743) 0.749583 0.784641 0.824708 (list 0.553909 0.351853 0.97743)) (list (list 0.553909 0.351853 0.97743) 0.824708 0.853088 0.876461 (list 1.0 0.0 1.0)) (list (list 1.0 0.0 1.0) 0.876461 0.943172 1.0 (list 1.0 1.0 0.0))))
