;;; kernel.scm --- 
   
;;;;   Copyright (C) 1997 GYVE Development Team
;;;;
;;;;   Author: Masatake YAMATO (masata-y@is.aist-nara.ac.jp)
;;;;   Created: Wed Oct 29 01:13:55 1997
;;;;   Time-stamp: <98/06/04 03:07:27 masata-y>
;;;;   
;;;;   This file is part of the GYVE vector based drawing editor. 
;;;;
;;;;   This program conforms GNU GENERAL PUBLIC LICENSE Version 2.

;; gyvekernel$B%Q%C%1!<%8$,;H$&$G$"$m$&JQ?t(B, $B4X?t72(B
;; $B%W%i%0%$%s%W%m%0%i%^$N$?$a$K(Bgyve:kernel:zzz$B$G$O$J$/(B
;; gyve:zzz$B$H$7$F@\F,<-$r$O$V$$$?(B. 

(define-module (gyve kernel) 
  :use-module (languages guileobjc)
  :use-module (gyve font)
  :use-module (gyve figs))

(define-public (gyve) ([] (objc-lookup-class "Gyve") application))
       
(define-public (gyve:current-window) ([] (gyve) currentWindow))
(define-public (gyve:current-buffer)  ([] (gyve) currentBuffer))

(define-public (gyve:current-buffer-safty)  
  (if (eq? (objc-get-nil) ([] (gyve) currentBuffer))
      (let* ((buf ([] (gyve) createNewBufferNamed: "*scratch*<0>"))
	     (win #f))
	([] (gyve) setBuffer: buf)
	(set! win ([] (gyve) createNewWindowBoundTo: buf))
	([] win map)
	([] (gyve) setWindow: win)
	buf)
      ([] (gyve) currentBuffer)))
	
(define-public (gyve:create-window-for buffer)
  (if buffer
      ([] (gyve) createNewWindowBoundTo: buffer)
      ([] (gyve) createNewWindowBoundTo: (current-buffer))))

(define-public (gyve:paint-style-manager)
  ([] (gyve) paintStyleManager))

(define-public (gyve:set-custom-color-to-fill r g b)
  ([] (gyve:paint-style-manager) setFillingPaintingApplication:
      (objc-new PSProcessColor initWithRed: r green: g blue: b)))

(define-public (gyve:set-custom-color-to-stroke r g b)
  ([] (gyve:paint-style-manager) setStrokingPaintingApplication:
      (objc-new PSProcessColor initWithRed: r green: g blue: b)))

(define-public (gyve:set-line-width width)
  ([] (gyve:paint-style-manager) setLineWidth: width))

(define-public (gyve:redraw-current-buffer)
  ([] (gyve:current-window) redrawAll))
(define-public  (gyve:clear-selections)
  ([] (gyve:current-buffer) clearSelectionsForGuile))

(define-public (gyve:selections)
  (let ((result '())
	(count ([] (gyve:current-buffer) countSelections))
	(sellayer ([] (gyve:current-buffer) selectionsLayer)))
    (while (< 0 count)
	   (set! result (cons ([] sellayer nthFigObjFromTop:  (1- count))
			      result))
	   (set! count (1- count)))
    result
    ))

(define-public (gyve:mark)
  (let* ((win (gyve:current-window))
	 (mark ([] win markAsId))
	 (x ([] mark pointValueX))
	 (y ([] mark pointValueY)))
    (list x y)))

(defmacro-public gyve:run-filter (script)
  `(gyve:put-fig-objs (let* ((sels (gyve:selections))
			    (gyve:MARK (gyve:mark))
			    (gyve:MARK:X (gyve:figs:x gyve:MARK))
			    (gyve:MARK:Y (gyve:figs:y gyve:MARK)))
			(map (lambda (gyve:TARGET) ,script)
			     sels
			     ))))

(defmacro-public gyve:run-generator (script)
  `(gyve:put-fig-objs (let* ((gyve:MARK (gyve:mark))
			     (gyve:MARK:X (gyve:figs:x gyve:MARK))
			     (gyve:MARK:Y (gyve:figs:y gyve:MARK)))
			,script)))

;; IDEA <Japanese>
;; $BBPOC<B9T$rA0Ds$H$7$?%3%^%s%I$,(B
;; #t$B$rJV$7$?$i%3%^%s%I$=$N%3%^%s%I$,;XDj$7$?@.8yJ8;zNs$r(B
;; #f$B$rJV$7$?$i%3%^%s%I$=$N%3%^%s%I$,;XDj$7$?<:GTJ8;zNs$r(B
;; driver$B4X?t$,I=<($9$k$C$F$N$O$I$&(B? Masatake
;; (gyve-interactive-command-register gyve:set-brush-width
;;                                    :if-sucess: "CHANGED!"
;;                                    :if-fail: "WRONG NUMBER!")
;; (gyve-interactive-call-top-level 'gyve:set-brush-width)
;; > CHANGED!
;; $B$^$!(B, lisp$B$J$s$s$G2?$G$b$G$-$k$1$I(B. 
;; </Japanese>
(define-public (gyve:set-brush-width size)
  (if (number? size)
      (begin ([] (objc-class GyveBrushTool) setBrushWidth: size) "CHANGED!")
      (begin "SIZE IS NOT NUMBER!")))

(define-public (gyve:put-fig-objs target)
  (let ((result #f))
    (gyve:clear-selections)
    (set! result (gyve:put-fig-objs-core target))
    (gyve:redraw-current-buffer)
    result))

(define (gyve:put-fig-objs-core target)
  (cond ((list? target)
	 (map (lambda (element)
		(gyve:put-fig-objs-core element))
	      target))
	((objc-id? target)
	 (gyve:kernel:put-fig-obj target))
	(else
	 "FAIL!"
	 )))

(define-public (gyve:kernel:put-fig-obj target) 
  (if (guileobjc-buggy-bool-return)
      (begin
	([] (gyve:current-buffer) putFigObjOnTopAndSelect: target)
	"WHAT'S HAPPENING?")
      (cond ((objc-bool ([] target conformsToProtocol: 
			    (objc-protocol GyveFigObj)))
	     ([] (gyve:current-buffer) putFigObjOnTopAndSelect: target) 
	     "SUCCESS!") 
	    ((objc-bool ([] target conformsToProtocol: 
			    (objc-protocol PSPath)))
	     ([] (gyve:current-buffer) putFigObjOnTopAndSelect: target) 
	     "SUCCESS!")
	    (else
	     "FAIL!"))))

(define-public (gyve:kernel:realize target)	  
   ([] (gyve:current-buffer) putFigObjOnTop: target))

(define-public (gyve:kernel:newpage)
  #f)
  

;;
;; Input string
;;
(define-public (gyve:put-string-paths string fontname size at)
  ([] (gyve:font:manager) 
      setInsertPointX: (gyve:figs:x at)
      andY: (gyve:figs:y at))
  ([] (gyve:font:manager) putString: string 
      onBuffer: (gyve:current-buffer-safty)
      withFont: fontname andSize: size)
  (gyve:redraw-current-buffer))