;;; simple-filter.scm --- 
   
;;;;   Copyright (C) 1997 GYVE Development Team
;;;;
;;;;   Author: Masatake YAMATO (masata-y@is.aist-nara.ac.jp)
;;;;   Created: Wed Oct 29 01:13:55 1997
;;;;   Time-stamp: <98/04/26 11:53:29 masata-y>
;;;;   
;;;;   This file is part of the GYVE vector based drawing editor. 
;;;;
;;;;   This program conforms GNU GENERAL PUBLIC LICENSE Version 2.
(define-module (gyve simple-filter) 
  :use-module (languages guileobjc)
  :use-module (gyve figs))

;;
;;
;;
(define-public (gyve:filter:randomize path-or-list xpercentage ypercentage)
  (cond
   ((list? path-or-list)
    (map (lambda (apath)
	   (gyve:filter:randomize apath xpercentage ypercentage))
	 path-or-list))
   ((objc-id? path-or-list)
    (let ((result (gyve:figs:create-path
		   (let* (;; Bbox
			  (bboxlist (gyve:figs:get-bbox path-or-list)) 
			  (ll (list-ref bboxlist 0))	; Lower Left(bbox)
			  (ur (list-ref bboxlist 1))	; Upper Right(bbox)
			  ;; Range of randomizing
			  (xpix (* 0.01 xpercentage (- (gyve:figs:x ur) (gyve:figs:x ll))))
			  (ypix (* 0.01 ypercentage (- (gyve:figs:y ur) (gyve:figs:y ll))))
			  ;; List expression of a path 
			  (aslist (gyve:figs:path->list path-or-list))
			  ;; random value generator
			  ;; ra -> Range of randomizing
			  ;; bval -> base value
			  ;; bval - ra < result < bval + ra
			  (rfunc (lambda (ra bval)
				   (gyve:figs:random-float 
				    (- bval
				       ra)
				    (+ bval
				       ra)))))
		     ;; Foreach segment
		     (map (lambda (target)
			    (let ((sym (list-ref target 0)))
			      (cond
			       ((or (eq? sym 'moveto) (eq? sym 'lineto))
				;; Create new segment
				(list sym
				      (rfunc xpix (list-ref target 1))
				      (rfunc ypix (list-ref target 2))))
			       ((eq? sym 'curveto)
				;; Create new segment
				(list sym
				      (rfunc xpix (list-ref target 1))
				      (rfunc ypix (list-ref target 2))
				      (rfunc xpix (list-ref target 3))
				      (rfunc ypix (list-ref target 4))
				      (rfunc xpix (list-ref target 5))
				      (rfunc ypix (list-ref target 6)))))))
			  aslist) 	

		     ))))
    (gyve:figs:set-painting
     result
     ([] (list-ref (gyve:figs:get-painting path-or-list) 0) copy)
     ([] (list-ref (gyve:figs:get-painting path-or-list) 1) copy))
    ;; <Japanese>XXX: $BB>$N%"%H%j%S%e!<%H$b%3%T!<$9$k$3$H(B</Japanese>
    (if (gyve:figs:is-closed-path? path-or-list)
	(gyve:figs:close-path result))
    result
    ))))

;;
;;
;;
(define-public (gyve:filter:neon path-or-list width color joinstyle)
  (cond 
   ((> 1 width)
    #f)
  ((list? path-or-list)
   (map (lambda (maybe-a-path)
	  (gyve:filter:neon path-or-list width color))
	path-or-list))
  ((objc-id? path-or-list)
   (let* ((close  (gyve:figs:is-closed-path? path-or-list))
	  (basewidth 1.0)
	  (widthstep 1.0)
	  (colorobj (gyve:figs:create-color color))
	  (rgb (gyve:figs:get-rgb colorobj))
	  ;;
	  (basered (list-ref rgb 0))
	  (basegreen (list-ref rgb 1))
	  (baseblue (list-ref rgb 2))
	  ;;
	  (redstep (/ (/ (- 1.0 basered) (- width basewidth)) 2.0))
	  (greenstep (/ (/ (- 1.0 basegreen) (- width basewidth)) 2.0))
	  (bluestep (/ (/ (- 1.0 baseblue) (- width basewidth)) 2.0))
	  (minred (- basered (- 1.0 basered)))
	  (mingreen (- basegreen (- 1.0 basegreen)))
	  (minblue (- baseblue (- 1.0 baseblue))))
     (do ((r 1.0 (- r redstep))
	  (g 1.0 (- g greenstep))
	  (b 1.0 (- b bluestep))
	  (result '())
	  (w basewidth (+ w widthstep))
	  (targetpath (gyve:figs:copy-path path-or-list)
		      (gyve:figs:copy-path path-or-list)))
	 ((< width w) result)
       (gyve:figs:set-color targetpath #t (list r g b))
       (gyve:figs:set-line-width targetpath w)
       (if close
	   (gyve:figs:close-path targetpath))
       (if (not (boolean? joinstyle))
	   (gyve:figs:set-line-join targetpath joinstyle))
       (set! result (cons targetpath result)))))))

;;
;;
;;
(define-public (gyve:filter:vector-blur path vector absolutely tofilling tostroking)
  (if absolutely
      (let* ((center (gyve:figs:get-center-of-path path))
	     (cx (gyve:figs:x center))
	     (cy (gyve:figs:y center))
	     (dx (- (gyve:figs:x vector) cx))
	     (dy (- (gyve:figs:y vector) cy))
	     (len (sqrt (+ (* dx dx) (* dy dy))))
	     (trmatrix (gyve:figs:create-trans-matrix (/ dx len) (/ dy len))))
	(gyve:filter:matrix-blur path trmatrix len 
				 tofilling
				 tostroking))
      (let* ((dx (gyve:figs:x vector))
	     (dy (gyve:figs:y vector))
	     (len (sqrt (+ (* dx dx) (* dy dy))))
	     (trmatrix (gyve:figs:create-trans-matrix (/ dx len) (/ dy len))))
	(gyve:filter:matrix-blur path trmatrix len 
				 tofilling
				 tostroking))))

(define-public (gyve:filter:matrix-blur path matrix step tofilling tostroking)
  (if (boolean? tofilling)
      (set! tofilling "white"))
  (if (boolean? tostroking)
      (set! tostroking "white"))
  (set! tofilling (gyve:figs:get-rgb (gyve:figs:create-color tofilling)))
  (set! tostroking (gyve:figs:get-rgb (gyve:figs:create-color tostroking)))
  (let* ((result (list path))
	 (last (gyve:figs:copy-path path))
	 (base (gyve:figs:get-painting path))
	 (base-f (car base))
	 (base-s (car (cdr base)))
	 (step-f #f)
	 (step-s #f)
	 (vector-dif (lambda (newcolor basecolor)
		       (list (/ (- (list-ref newcolor 0)
				   (list-ref basecolor 0)) 
				step)
			     (/ (- (list-ref newcolor 1)
				   (list-ref basecolor 1))
				step)
			     (/ (- (list-ref newcolor 2)
				   (list-ref basecolor 2))
				step))))
	 (vector-add (lambda (a b)
		       (list (+ (list-ref a 0) (list-ref b 0)) 
			     (+ (list-ref a 1) (list-ref b 1))
			     (+ (list-ref a 2) (list-ref b 2))))))
    (if (eq? (objc-get-nil) base-f)
	(set! base-f #f)
	(set! base-f (gyve:figs:get-rgb base-f)))
    (if (eq? (objc-get-nil) base-s)
	(set! base-s #f)
	(set! base-s (gyve:figs:get-rgb base-s)))
    (if base-f
	(set! step-f (vector-dif tofilling base-f))
	(set! step-f #f))
    (if base-s
	(set! step-s (vector-dif tostroking base-s))
	(set! step-s #f))
    (set! step (1- step))			;XXX???
    (while (< 0 step)
	   (gyve:figs:apply-matrix last matrix)
	   (if base-s
	       (begin
		 (set! base-s (vector-add base-s step-s))
		 (gyve:figs:set-color last #f base-s)))
	   (if base-f
	       (begin
		 (set! base-f (vector-add base-f step-f))
		 (gyve:figs:set-color last base-f #f)))
	   (set! result (cons last result))
	   (set! last (gyve:figs:copy-path last))
	   (set! step (1- step)))
    (reverse result)))

(define-public (gyve:filter:points-twice path)
  (cond 
   ((list? path)
    (map (lambda (apath)
	   (gyve:filter:points-twice apath)
	   path)))
   ((objc-id? path)
    (let* ((close (gyve:figs:is-closed-path? path))
	   (pathspec (gyve:figs:path->list path))
	   (moveto0  (car pathspec))
	   (currentpoint (cdr moveto0))
	   (last-point (lambda (segspec)
			 (cond
			  ((or (eq? (car segspec) 'moveto) 
			       (eq? (car segspec) 'lineto))
			   (cdr segspec))
			  ((eq? (car segspec) 'curveto)
			   (list (list-ref (cdr segspec) 4)
				 (list-ref (cdr segspec) 5))))))
	   (pair #f)
	   (resultlist '())
	   (resultpath #f)
	   )
      (set! pathspec (cdr pathspec))
      (for-each (lambda (segmentspec)
		 (set! pair (gyve:figs:split-segment currentpoint segmentspec 0.5))
		 (set! resultlist (cons (car pair) resultlist))
		 (set! resultlist (cons (car (cdr pair)) resultlist))
		 (set! currentpoint (last-point segmentspec)))
	       pathspec)
      
      ;; <Japanese>XXX: $BB>$N%"%H%j%S%e!<%H$r%3%T!<$9$k$3$H(B</Japanese>
      (set! resultpath (gyve:figs:create-path  (cons moveto0 (reverse resultlist))))
      (if close
	  (gyve:figs:close-path resultpath))
      resultpath
      ))))


;; *STILL UNDER WORK*
;; (FIELD segmenttype x y pointtype)
;; segmenttype ==  'moveto|'lineto|'curveto
;; pointtype   ==  'anchor|'direction
(define-public (gyve:filter:vector-field-apply target field)
  (let ((segmenttype #f)
	(pointtype #f)
	(x #f)
	(y #f)
	(listedpath (gyve:figs:path->list))
	(listedresult #f))
    (set! listedresult
	  (map (lambda (segment)
		 (cond
		  ((eq? (car segment) 'curveto)
		   (append (list 'curveto)
			   (field 'curveto 
				  (list-ref segment 1) (list-ref segment 2)
				  'direction)
			   (field 'curveto 
				  (list-ref segment 3) (list-ref segment 4)
				  'direction)
			   (field 'curveto 
				  (list-ref segment 5) (list-ref segment 6)
				  'anchor)
			   '()))
		  (else
		   (append (list (car segment))
			   (field (car segment) 
				  (list-ref segment 1) (list-ref segment 2) 
				  'anchor)))))
	       listedpath))
    (gyve:figs:create-path listedresult)))


