;;; simple-generator.scm --- 
   
;;;;   Copyright (C) 1997 GYVE Development Team
;;;;
;;;;   Author: Masatake YAMATO (masata-y@is.aist-nara.ac.jp)
;;;;   Created: Wed Oct 29 01:13:55 1997
;;;;   Time-stamp: <98/03/29 14:19:34 masata-y>
;;;;   
;;;;   This file is part of the GYVE vector based drawing editor. 
;;;;
;;;;   This program conforms GNU GENERAL PUBLIC LICENSE Version 2.
(define-module (gyve simple-generator) 
  :use-module (languages guileobjc)
  :use-module (gyve figs))


;; public
(define-public (gyve:generator:roundbox radiusx radiusy roundseed centerx centery )
  (let ((roundseedx (* roundseed radiusx))
	(roundseedy (* roundseed radiusy)))
    (gyve:figs:close-path
     (gyve:figs:create-path
      (list 
       ;; x
       (list 'moveto 
	     centerx
	     (+ centery radiusy))
       ;; a
       (list 'curveto 
	     (+ centerx roundseedx)
	     (+ centery radiusy)
	     (+ centerx radiusx)
	     (+ centery roundseedy)
	     (+ centerx radiusx)
	     centery)
       ;; b
       (list 'curveto 
	     (+ centerx radiusx)
	     (- centery roundseedy)
	     (+ centerx roundseedx)
	     (- centery radiusy)
	     centerx
	     (- centery radiusy))
       ;; c
       (list 'curveto
	     (- centerx roundseedx)
	     (- centery radiusy)
	     (- centerx radiusx)
	     (- centery roundseedy)
	     (- centerx radiusx)
	     centery)
       ;; d
       (list 'curveto
	     (- centerx radiusx)
	     (+ centery roundseedy)
	     (- centerx roundseedx)
	     (+ centery radiusy)
	     centerx
	     (+ centery radiusy)))))
    ))

;; public
(define-public (gyve:generator:circle radius center)
  (gyve:generator:roundbox  radius radius 0.54 (gyve:figs:x center) (gyve:figs:y center)))
	       
;; public
(define-public (gyve:generator:star edges first-radius second-radius center)
  (let* ((result '())
	 (pi (* 2 ($acos 0)))
	 (next-edge-len #f)
	 (edge-step 0)
	 (seed-angle (/ (/  (* pi 2) edges) 2))
	 (current-angle (/ pi 2))
	 (toggle (lambda (len)
		   (if (eqv? len first-radius)
		       second-radius
		       first-radius)))
	 (cx (gyve:figs:x center))
	 (cy (gyve:figs:y center)))
    (if (odd? edges)
	(set! next-edge-len first-radius)
	(set! next-edge-len second-radius))
    
    (set! result (cons (list 'moveto 
			     cx
			     (+ cy next-edge-len)) result))
    (while (< edge-step edges)
	   (set! next-edge-len (toggle next-edge-len))
	   (set! current-angle (+ current-angle seed-angle))
	   (set! result (cons 
			 (list 'lineto
			       (+ (* ($cos current-angle) next-edge-len) cx)
			       (+ (* ($sin current-angle) next-edge-len) cy))
			 result))
	   
	   (set! current-angle (+ current-angle seed-angle))
	   (set! next-edge-len (toggle next-edge-len))
	   (set! result (cons 
			 (list 'lineto
			       (+ (* ($cos current-angle) next-edge-len) cx)
			       (+ (* ($sin current-angle) next-edge-len) cy))
			 result))
	   (set! edge-step (+ edge-step 1)))
    (gyve:figs:close-path (gyve:figs:create-path (reverse result)))))

;; public
(define-public (gyve:generator:spiral loop-depth radius closewise center)
  (let* ((exstep (/ radius (+ loop-depth 0.5)))
	 (rseed (/ (/ (+ radius exstep) (+ loop-depth 1)) 4))
	 (max-step (* 4 loop-depth))
	 (current-step 0)
	 (current-radius radius)
	 (next-radius (lambda (r s) (- r s)))
	 (calc-handle-len (lambda (r) (* 0.55 r)))
	 (result '())
	 (cx (gyve:figs:x center))
	 (cy (gyve:figs:y center)))
    ;;
    (set! result (cons (list 'moveto (+ cx current-radius) cy)
		       result))
    (if closewise
	(while (< current-step max-step)
	       (set! result
		     (cons (list 'curveto 
				 (+ cx current-radius)
				 (- cy (calc-handle-len current-radius))
				 (+ cx (calc-handle-len current-radius))
				 (- cy current-radius)
				 cx
				 (- cy current-radius))
			   result))
	       (set! current-radius (next-radius current-radius rseed))
	       (set! current-step (+ current-step 1))

	       (set! result
		     (cons (list 'curveto 
				 (- cx (calc-handle-len current-radius))
				 (- cy current-radius)
				 (- cx current-radius)
				 (- cy (calc-handle-len current-radius))
				 (- cx current-radius)
				 cy)
			   result))
	       (set! current-radius (next-radius current-radius rseed))
	       (set! current-step (+ current-step 1))

	       (set! result
		     (cons (list 'curveto 
				 (- cx current-radius)
				 (+ cy (calc-handle-len current-radius))
				 (- cx (calc-handle-len current-radius))
				 (+ cy current-radius)
				 cx
				 (+ cy current-radius))
			   result))

	       (set! current-radius (next-radius current-radius rseed))
	       (set! current-step (+ current-step 1))

	       (set! result
		     (cons (list 'curveto 
				 (+ cx (calc-handle-len current-radius))
				 (+ cy current-radius)
				 (+ cx current-radius)
				 (+ cy (calc-handle-len current-radius))
				 (+ cx current-radius)
				 cy)
			   result))
	       (set! current-radius (next-radius current-radius rseed))
	       (set! current-step (+ current-step 1)))
	  (while (< current-step max-step)
		 (set! result
		       (cons (list 'curveto 
				   (+ cx current-radius)
				   (+ cy (calc-handle-len current-radius))
				   (+ cx (calc-handle-len current-radius))
				   (+ cy current-radius)
				   cx
				   (+ cy current-radius))
			     result))
		 (set! current-radius (next-radius current-radius rseed))
		 (set! current-step (+ current-step 1))
		 
		 (set! result
		       (cons (list 'curveto 
				   (- cx (calc-handle-len current-radius))
				   (+ cy current-radius)
				   (- cx current-radius)
				   (+ cy (calc-handle-len current-radius))
				   (- cx current-radius)
				   cy)
			     result))
		 (set! current-radius (next-radius current-radius rseed))
		 (set! current-step (+ current-step 1))
	
		 (set! result
		       (cons (list 'curveto 
				   (- cx current-radius)
				   (- cy (calc-handle-len current-radius))
				   (- cx (calc-handle-len current-radius))
				   (- cy current-radius)
				   cx
				   (- cy current-radius))
			     result))
		 (set! current-radius (next-radius current-radius rseed))
		 (set! current-step (+ current-step 1))

		 (set! result
		       (cons (list 'curveto 
				   (+ cx (calc-handle-len current-radius))
				   (- cy current-radius)
				   (+ cx current-radius)
				   (- cy (calc-handle-len current-radius))
				   (+ cx current-radius)
				   cy)
			     result))
		 (set! current-radius (next-radius current-radius rseed))
		 (set! current-step (+ current-step 1))))
    (gyve:figs:create-path (reverse result))))

;; public    
(define-public (gyve:generator:polygon edges radius center)
  (let* ((result '())
	 (cx (gyve:figs:x center))
	 (cy (gyve:figs:y center))
	 (pi (* 2 ($acos 0)))
	 (seed-angle (/ (* 2 pi) edges))
	 (currnet-angle (/ pi 2))
	 (currnet-step 0))
    (set! result (cons (list 'moveto cx (+ cy radius)) result))
    (while (< currnet-step edges)
	   (set! currnet-step (+ currnet-step 1))
	   (set! currnet-angle (- currnet-angle seed-angle))
	   (set! result (cons (list 'lineto
				    (+ cx (* ($cos currnet-angle) radius))
				    (+ cy (* ($sin currnet-angle) radius)))
			      result)))
    (gyve:figs:create-path (reverse result))))

;; public
(define (gyve:generator:fan begin end radius center)
  ; Still under work
  #f)

;; public
;; Inspired by the jacket of CD, niji/DenkiGroove.
(define-public (gyve:generator:NIJI basecolorlist size center)
  (if (boolean? size)
      (set! size 900))
  (if (boolean? center)
      (set! center (list 0 0)))
  (let ((currentradius 0)
	(incvalset (list 2 8 4 1))
	(colorset (list 
		   "DarkSeaGreen2"
		   "light blue"
		   "LightCyan2"
		   "SteelBlue"))
	(result '()))
    (while (< currentradius size)
	   (set! result (cons (gyve:generator:circle currentradius 
						     center) result))
	   (set! currentradius (+ currentradius 
				  (list-ref incvalset 
					    (gyve:figs:random-int 0 3)))))
    (map (lambda (path)
	      (gyve:figs:set-color path (list-ref colorset 
						  (gyve:figs:random-int 0 3)) #f))
	    result)))

;; public
(define-public (gyve:generator:random-lines  step)
  (let ((result '()))
    (while (< 0 step)
	   (set! step (- step 1))
	   (set! result (cons (list 'lineto
				    (gyve:figs:random-float 0 500)
				    (gyve:figs:random-float 0 500))
			      result)))
    (set! result (cons (list 'moveto
			     (gyve:figs:random-float 0 500)
			     (gyve:figs:random-float 0 500))
		       result))
    (gyve:figs:create-path result)))

;; end of simple-generator.scm
