;;; utils.scm --- 

;;;;   Copyright (C) 1998 GYVE Development Team
;;;;
;;;;   Author: Eiichi TAKAMORI (taka@ma1.seikyou.ne.jp)
;;;;   Created: Thu Apr  2 00:02:21 1998
;;;;   Time-stamp: <98/05/24 10:51:41 masata-y>
;;;;   
;;;;   This file is part of the GYVE vector based drawing editor. 
;;;;
;;;;   This program conforms GNU GENERAL PUBLIC LICENSE Version 2.

(define-module (gyve utils))

(define pretty-print write)
;;
;; Convert gimp gradient in a FILE into gyve gradation
;;
(define-public (gyve:utils:convert-gradient filename gradient-name)
  (with-input-from-file filename
    (lambda ()
      (if (not (string=? (read-line) "GIMP Gradient"))
	  (error "not a gradient" filename))
      (do ((nsegs (read))
	   (i 0 (1+ i))
	   (segs '()))
	  ((>= i nsegs)
	   (pretty-print `(define-gradation ,gradient-name
			    (list ,@(reverse segs))))
	   (newline))
	(let ((left (read))
	      (middle (read))
	      (right (read))
	      (r0 (read))
	      (g0 (read))
	      (b0 (read))
	      (a0 (read))
	      (r1 (read))
	      (g1 (read))
	      (b1 (read))
	      (a1 (read))
	      (type (read))
	      (color (read)))
	  (set! segs (cons `(list (list ,r0 ,g0 ,b0)
				  ,left ,middle ,right
				  (list ,r1 ,g1 ,b1))
			   segs)))))))

;;
;; Convert gimp gradient in FILES in a directory into gyve gradation
;;

(define-public (gyve:utils:convert-all-gradients directory)
  (let ((dir (opendir directory))
	(pathname #f))
    (do ((filename (readdir dir) (readdir dir)))
	((eof-object? filename) (closedir dir))
      (set! pathname (string-append directory "/" filename))
      (and (eq? 'regular (stat:type (stat pathname)))
	   (gyve:utils:convert-gradient pathname filename)))))

;; Usage:
;; (gyve:utils:convert-all-gradients "/usr/local/share/gimp/gradients")
;; 
